@@ -1,4 +1,5 @@
 pub mod rpc;
+pub mod util;
 
 use async_trait::async_trait;
 use futures::{
@@ -162,6 +163,14 @@ pub struct Context<W: Clone> {
     deferred: DeferredTasks,
 }
 
+impl<W: Clone> std::ops::Deref for Context<W> {
+    type Target = W;
+
+    fn deref(&self) -> &Self::Target {
+        &self.world
+    }
+}
+
 impl<W: Clone> Context<W> {
     pub async fn is_initialized(&self) -> bool {
         self.inner.lock().await.initialized
@@ -171,8 +180,8 @@ impl<W: Clone> Context<W> {
         self.inner.lock().await.shutting_down
     }
 
-    pub fn world(&mut self) -> &mut W {
-        &mut self.world
+    pub fn world(&self) -> &W {
+        &self.world
     }
 
     pub fn cancel_token(&mut self) -> &mut CancelToken {
